@@ -109,8 +109,6 @@ def parse_pbn(file_lines):
     play_state = False
     board_state = False
     events = []
-    event = Event(DEFAULT_EVENT_NAME)
-    events.append(event)
     board = None
     value = None
     for line in file_lines:
@@ -157,7 +155,11 @@ def parse_pbn(file_lines):
                 if current_board_identifier != board_identifier:
                     current_board_identifier = board_identifier
                     board = Board(board_identifier)
+                    if not event:
+                        event = Event(DEFAULT_EVENT_NAME)
+                        events.append(event)
                     event.boards.append(board)
+                    # print('xxx', event, events)
                     trick_index = 0
 
             # Board West
